@@ -60,7 +60,7 @@ def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting:
     interests = ql.FixedRateLeg(schedule, 
                             ql_day_count[setting.day_count],
                             [bond_info.face_value], 
-                            [bond_info.coupon])
+                            [bond_info.coupon/100])
     no_of_interests = len(interests)
     structures = []
     for i in range(no_of_interests):
